From bc46afb34524d97a354a636c476544daedf560cd Mon Sep 17 00:00:00 2001
From: Ian Jackson <ijackson@chiark.greenend.org.uk>
Date: Fri, 21 Jan 2022 19:51:25 +0000
Subject: [PATCH 3/4] * inotify.c: Break out inotify_process_buffer

We pass the buffer fullness in a global variable.  This is weird right
now, but we are going to want this to persist so it is convenient to
do it now.
---
 src/inotify.c | 13 ++++++++++++-
 1 file changed, 12 insertions(+), 1 deletion(-)

diff --git a/src/inotify.c b/src/inotify.c
index ad02164b37..8a3685f2f1 100644
--- a/src/inotify.c
+++ b/src/inotify.c
@@ -44,6 +44,7 @@ Copyright (C) 2012-2022 Free Software Foundation, Inc.
 static int inotifyfd = -1;
 
 static size_t inotify_buffer_len = 0;
+static size_t inotify_buffer_full = 0;
 static char *inotify_buffer = NULL;
 
 /* Alist of files being watched.  We want the returned descriptor to
@@ -71,6 +72,9 @@ Copyright (C) 2012-2022 Free Software Foundation, Inc.
 
 static Lisp_Object watch_list;
 
+static void
+inotify_process_buffer (void);
+
 static Lisp_Object
 mask_to_aspects (uint32_t mask)
 {
@@ -332,11 +336,18 @@ inotify_callback (int fd, void *_)
   if (n < 0)
     report_file_notify_error ("Error while reading file system events", Qnil);
 
+  inotify_buffer_full = n;
+  inotify_process_buffer ();
+}
+
+static void
+inotify_process_buffer (void)
+{
   struct input_event event;
   EVENT_INIT (event);
   event.kind = FILE_NOTIFY_EVENT;
 
-  for (ssize_t i = 0; i < n; )
+  for (ssize_t i = 0; i < inotify_buffer_full; )
     {
       struct inotify_event *ev = (struct inotify_event *) &inotify_buffer[i];
       Lisp_Object descriptor = INT_TO_INTEGER (ev->wd);
-- 
2.20.1

